//
//  ContentView+Extension.swift
//  ContentView+Extension
//
//  Created by Stewart Lynch on 2021-08-08.
//

import SwiftUI

extension ContentView {
    var listRow: some View {
        ForEach($dataStore.filteredToDos) { $toDo in
            TextField(toDo.name, text: $toDo.name)
                    .font(.title3)
                    .foregroundColor(toDo.completed ? .green : Color(.label))
                    .focused($focusedField, equals: true)
                    .overlay(
                    Rectangle()
                        .fill(Color.green)
                        .frame(height: 1)
                        .opacity(toDo.completed ? 1 : 0)
                    )
                    .onSubmit {
                        dataStore.updateToDo(toDo)
                    }
            .swipeActions {
                Button(role: .destructive) {
                    withAnimation {
                        dataStore.deleteToDo(toDo)
                    }
                } label: {
                    Label("Delete", systemImage: "trash")
                }
            }
            .swipeActions(edge: .leading) {
                Button {
                    toDo.completed.toggle()
                    dataStore.updateToDo(toDo)
                } label: {
                    Text(toDo.completed ? "Remove Completion" : "Completed")
                }.tint(.teal)
            }
        }
    }
}
